@@ -14,7 +14,7 @@ if (!isGeneric("KML")) {
 
 setMethod('KML', signature(x='RasterLayer'), 
 
-function (x, filename, col=rev(terrain.colors(255)), maxpixels=100000, zip='', ...) {
+function (x, filename, col=rev(terrain.colors(255)), maxpixels=100000, blur=1, zip='', ...) {
 
     if (! .couldBeLonLat(x)) { 
         stop("CRS of x must be longitude / latitude")
@@ -36,13 +36,9 @@ function (x, filename, col=rev(terrain.colors(255)), maxpixels=100000, zip='', .
 	kmlfile <- filename
 	extension(kmlfile) <- '.kml'
 
-	png(filename = imagefile, width=max(480, ncol(x)), height=max(480, nrow(x)), bg="transparent")
+	png(filename = imagefile, width=max(480, blur*ncol(x)), height=max(480,blur*nrow(x)), bg="transparent")
 	par(mar=c(0,0,0,0))
-	if (R.Version()$minor >= 13) {
-		image(x, col=col, axes=FALSE, useRaster=TRUE, ...)
-	} else {
-		image(x, col=col, axes=FALSE, ...)	
-	}
+	image(x, col=col, axes=FALSE, useRaster=TRUE, ...)
 	dev.off()
 
 	name <- layerNames(x)[1]
