@@ -36,13 +36,13 @@ function(x, y, ...){
 
 
 setMethod('rasterize', signature(x='SpatialPolygons', y='Raster'), 
-function(x, y, ...){ 
+function(x, y, field, ...){ 
 	.polygonsToRaster(x, y, ...)
 })
 
 setMethod('rasterize', signature(x='Extent', y='Raster'), 
  	function(x, y, ...) {
-		y <- polygonFromExtent(y)
+		y <- as(y, 'SpatialPolygons')
 		.polygonsToRaster(x, y, ...)
 	}
 )
